@@ -7,7 +7,7 @@ class I2C:
 
     def __init__(self, *, frequency=100000):
         self._mcp2221 = mcp2221
-        self._mcp2221.i2c_configure(frequency)
+        self._mcp2221._i2c_configure(frequency)
 
     def scan(self):
         """Perform an I2C Device Scan"""
@@ -32,7 +32,7 @@ class I2C:
         out_end=None,
         in_start=0,
         in_end=None,
-        stop=False
+        stop=False,
     ):
         """Write data from buffer_out to an address and then
         read data from an address and into buffer_in
