@@ -30,6 +30,20 @@ elif detector.chip.STM32MP157:
 elif "sphinx" in sys.modules:
     pass
 elif detector.board.pico_u2if:
-    from adafruit_blinka.microcontroller.pico_u2if.analogio import AnalogIn
+    from adafruit_blinka.microcontroller.rp2040_u2if.analogio import (
+        AnalogIn_Pico as AnalogIn,
+    )
+elif detector.board.feather_u2if:
+    from adafruit_blinka.microcontroller.rp2040_u2if.analogio import (
+        AnalogIn_Feather as AnalogIn,
+    )
+elif detector.board.qtpy_u2if:
+    from adafruit_blinka.microcontroller.rp2040_u2if.analogio import (
+        AnalogIn_QTPY as AnalogIn,
+    )
+elif detector.board.itsybitsy_u2if:
+    from adafruit_blinka.microcontroller.rp2040_u2if.analogio import (
+        AnalogIn_ItsyBitsy as AnalogIn,
+    )
 else:
     raise NotImplementedError("analogio not supported for this board.")
