@@ -89,6 +89,7 @@ elif (
     detector.board.feather_u2if
     or detector.board.qtpy_u2if
     or detector.board.itsybitsy_u2if
+    or detector.board.macropad_u2if
     or detector.board.qt2040_trinkey_u2if
 ):
     from adafruit_blinka.microcontroller.rp2040_u2if.pin import Pin
@@ -176,7 +177,7 @@ class DigitalInOut(ContextManaged):
 
     @property
     def value(self):
-        """Get or Set the Digital Pin Value"""
+        """The Digital Pin Value"""
         return self._pin.value() == 1
 
     @value.setter
@@ -188,7 +189,7 @@ class DigitalInOut(ContextManaged):
 
     @property
     def pull(self):
-        """Get or Set the Digital Pin Direction"""
+        """The pin pull direction"""
         if self.direction is Direction.INPUT:
             return self.__pull
         raise AttributeError("Not an input")
@@ -215,7 +216,7 @@ class DigitalInOut(ContextManaged):
 
     @property
     def drive_mode(self):
-        """Get or Set the Digital Pin Drive Mode"""
+        """The Digital Pin Drive Mode"""
         if self.direction is Direction.OUTPUT:
             return self.__drive_mode  #
         raise AttributeError("Not an output")
